@@ -6,6 +6,7 @@ from inspect import signature
 from pathlib import Path
 from contextlib import contextmanager
 import json
+import copy
 
 from .parser import ArgumentParser, HelpFormatter
 from .util import Arg, ArgparseArg, get_arg, join_strings, format_type, format_table
@@ -249,6 +250,15 @@ class Radicli:
         )
         self.commands[name] = dummy
 
+    def call(self, command: Command, args: Optional[List[str]] = None) -> None:
+        """Call a single command."""
+        run_args = args if args is not None else [*sys.argv[1:]]
+        cmd = copy.deepcopy(command)
+        cmd.name = ""  # for nicer display in help text
+        values = self.parse(run_args, cmd)
+        with self.handle_errors():
+            command.func(**values)
+
     def run(self, args: Optional[List[str]] = None) -> None:
         """
         Run the CLI. Should typically be used in the __main__.py nested under a
@@ -290,7 +300,9 @@ class Radicli:
         try:
             yield
         except tuple(errors_map.keys()) as e:
-            handler = errors_map[e.__class__]
+            handler = errors_map.get(e.__class__)
+            if not handler:
+                raise e
             err_code = handler(e)
             if err_code is not None:
                 sys.exit(err_code)
